@@ -68,57 +68,34 @@ class SignOperator(Enum):
 
 @dataclass
 class Field:
-    column: str
+    column: Optional[str] = None
     aggregation: Optional[Union[SQLFunction, TimeDimensionGranularity, str]] = None
     dataset: Optional[str] = None
     entityType: Optional[str] = None
     alias: Optional[str] = None
+    complexExpression: Optional[str] = None
     internalDataType: Optional[str] = None
     sourceDataType: Optional[str] = None
     sqlExpression: Optional[str] = None
     sourceFormat: Optional[str] = None
 
     def __repr__(self):
-        if self.aggregation is not None:
-            if isinstance(self.aggregation, SQLFunction) or isinstance(self.aggregation,
-                                                                        TimeDimensionGranularity):
-                field_with_agg = self.aggregation.name + " ( " + self.column + " )"
+        if self.column is not None:
+            if self.aggregation is not None:
+                if isinstance(self.aggregation, SQLFunction) or isinstance(self.aggregation,
+                                                                            TimeDimensionGranularity):
+                    field_with_agg = self.aggregation.name + " ( " + self.column + " )"
+                else:
+                    field_with_agg = self.aggregation + " ( " + self.column + " )"
             else:
-                field_with_agg = self.aggregation + " ( " + self.column + " )"
-        else:
-            field_with_agg = self.column
+                field_with_agg = self.column
+        elif self.complexExpression is not None:
+            field_with_agg = self.complexExpression
         if self.alias is not None:
             field_with_agg += " AS " + self.alias
         return field_with_agg
 
 
-class MathOperator(Enum):
-    ADD = "+"
-    MUL = "*"
-    SUB = "-"
-    DIV = "/"
-
-
-@dataclass
-class ComplexMathField:
-    first_operand: Union[float, Field, str]
-    operator: Union[MathOperator, str]
-    second_operand: Union[float, Field, str]
-    percent: Optional[bool] = None
-    alias: Optional[str] = None
-
-    def __repr__(self):
-        if isinstance(self.operator, MathOperator):
-            repr = str(self.first_operand) + " " + self.operator.value + " " + str(self.second_operand)
-        else:
-            repr = str(self.first_operand) + " " + self.operator + " " + str(self.second_operand)
-        if self.percent is not None and self.percent:
-            repr += " %"
-        if self.alias is not None:
-            repr += " AS " + self.alias
-        return repr
-
-
 class SQLOperator(Enum):
     EQ = auto()
     NOT_EQ = auto()
@@ -133,60 +110,10 @@ class SQLOperator(Enum):
     FOREACH = auto()
 
 
-@dataclass
-class ComplexConditionalField:
-    field: Union[str, Field]
-    operator: Union[SQLOperator, str]
-    value: Union[bool, float, str]
-    else_clause: Union[bool, float, str]
-    then_clause: Optional[Union[bool, float, str]] = None
-    alias: Optional[str] = None
-
-    def __repr__(self):
-        if isinstance(self.operator, SQLOperator):
-            repr = str(self.field) + " " + self.operator.name + " " + str(self.value)
-        else:
-            repr = str(self.field) + " " + self.operator + " " + str(self.value)
-        repr += " THEN"
-        if self.then_clause is not None:
-            repr += " " + str(self.then_clause)
-        repr += " ELSE " + str(self.else_clause)
-        if self.alias is not None:
-            repr += " AS " + self.alias
-        return repr
-
-
 class PatternOperator(Enum):
     START = auto()
     END = auto()
     CONTAINS = auto()
-    REPLACE = auto()
-    FIND = auto()
-    LEN = auto()
-    REMOVE = auto()
-
-
-@dataclass
-class ComplexPatternField:
-    field: Field
-    operator: Union[PatternOperator, str]
-    source_pattern: Optional[str] = None
-    target_pattern: Optional[str] = None
-    alias: Optional[str] = None
-
-    def __repr__(self):
-        if isinstance(self.operator, PatternOperator):
-            repr = self.operator.name
-        else:
-            repr = self.operator
-        if self.source_pattern is not None:
-            repr += " " + self.source_pattern
-        if self.target_pattern is not None:
-            repr += " with " + self.target_pattern
-        repr += " " + str(self.field)
-        if self.alias is not None:
-            repr += " AS " + self.alias
-        return repr
 
 
 class BooleanOperator(Enum):
@@ -278,29 +205,10 @@ class Condition:
         return where_condition
 
 
-@dataclass
-class ComplexMathCondition:
-    field: ComplexMathField
-    operator: Union[SQLOperator, str]
-    value: List[Union[float, str]] = None
-
-    def __repr__(self):
-        repr = str(self.field)
-        if isinstance(self.operator, SQLOperator):
-            repr += " " + change_operator(self.operator.name)
-        else:
-            repr += " " + self.operator
-        values = []
-        for var in self.value:
-            values.append(str(var))
-        repr += " ( " + ", ".join(values) + " )"
-        return repr
-
-
 @dataclass
 class CompositeCondition:
     operator: Union[BooleanOperator, str]
-    conditions: List[Union[Condition, ComplexMathCondition, 'CompositeCondition']]
+    conditions: List[Union[Condition, 'CompositeCondition']]
 
     def __repr__(self):
         if isinstance(self.operator, BooleanOperator):
@@ -370,12 +278,12 @@ class GroupBy:
 
 @dataclass
 class Query:
-    fields: List[Union[Field, ComplexMathField, ComplexConditionalField, ComplexPatternField]]
+    fields: List[Union[Field]]
     pivot: Optional[List[Field]] = None
     join: Optional[List[Join]] = None
     id: Optional[str] = None
     datasets: Optional[List[From]] = None
-    where: Optional[List[Union[Condition, ComplexMathCondition, CompositeCondition]]] = None
+    where: Optional[List[Union[Condition, CompositeCondition]]] = None
     groupBy: Optional[List[GroupBy]] = None
     orderBy: Optional[List[Sorting]] = None
     limit: Optional[Union[int, str]] = None
